@@ -2,7 +2,7 @@
 ################################################################################
 #
 #  Rattail -- Retail Software Framework
-#  Copyright © 2010-2020 Lance Edgar
+#  Copyright © 2010-2021 Lance Edgar
 #
 #  This file is part of Rattail.
 #
@@ -53,15 +53,17 @@ class ConfigExtension(BaseExtension):
         config.setdefault('tailbone', 'themes.expose_picker', 'true')
 
 
+def csrf_token_name(config):
+    return config.get('tailbone', 'csrf_token_name', default='_csrf')
+
+
+def csrf_header_name(config):
+    return config.get('tailbone', 'csrf_header_name', default='X-CSRF-TOKEN')
+
+
 def global_help_url(config):
     return config.get('tailbone', 'global_help_url')
 
 
-def legacy_mobile_enabled(config):
-    return config.getbool('tailbone', 'legacy_mobile.enabled',
-                          default=True)
-
-
 def protected_usernames(config):
     return config.getlist('tailbone', 'protected_usernames')
-
