@@ -2,7 +2,7 @@
 ################################################################################
 #
 #  Rattail -- Retail Software Framework
-#  Copyright © 2010-2021 Lance Edgar
+#  Copyright © 2010-2022 Lance Edgar
 #
 #  This file is part of Rattail.
 #
@@ -197,7 +197,7 @@ class Grid(object):
         """
         Mark the given column as "invisible" (but do not remove it).
 
-        Use :meth:`hide_column()` if you actually want to remove it.
+        Use :meth:`remove()` if you actually want to remove it.
         """
         if invisible:
             if key not in self.invisible:
@@ -217,7 +217,7 @@ class Grid(object):
 
     def replace(self, oldfield, newfield):
         self.insert_after(oldfield, newfield)
-        self.hide_column(oldfield)
+        self.remove(oldfield)
 
     def set_joiner(self, key, joiner):
         if joiner is None:
