@@ -2,7 +2,7 @@
 ################################################################################
 #
 #  Rattail -- Retail Software Framework
-#  Copyright © 2010-2020 Lance Edgar
+#  Copyright © 2010-2021 Lance Edgar
 #
 #  This file is part of Rattail.
 #
@@ -38,7 +38,9 @@ from rattail.db.util import maxlen
 from webhelpers2.html import *
 from webhelpers2.html.tags import *
 
-from tailbone.util import csrf_token, get_csrf_token, pretty_datetime, raw_datetime
+from tailbone.util import (csrf_token, get_csrf_token,
+                           pretty_datetime, raw_datetime,
+                           route_exists)
 
 
 def pretty_date(date):
