@@ -80,6 +80,23 @@ const GridFilter = {
             return true
         },
 
+        multiValuedVerb() {
+            /* this returns true if the filter's current verb should expose a multi-value input */
+
+            // if filter has no "multi-value" verbs then we safely assume false
+            if (!this.filter.multiple_value_verbs) {
+                return false
+            }
+
+            // if filter *does* have multi-value verbs, see if "current" is one
+            if (this.filter.multiple_value_verbs.includes(this.filter.verb)) {
+                return true
+            }
+
+            // current verb is not multi-value
+            return false
+        },
+
         focusValue: function() {
             this.$refs.valueInput.focus()
             // this.$refs.valueInput.select()
