@@ -2,7 +2,7 @@
 ################################################################################
 #
 #  Rattail -- Retail Software Framework
-#  Copyright © 2010-2021 Lance Edgar
+#  Copyright © 2010-2022 Lance Edgar
 #
 #  This file is part of Rattail.
 #
@@ -277,8 +277,9 @@ class CustomerOrderView(MasterView):
         return text
 
     def get_batch_handler(self):
-        return get_batch_handler(
-            self.rattail_config, 'custorder',
+        app = self.get_rattail_app()
+        return app.get_batch_handler(
+            'custorder',
             default='rattail.batch.custorder:CustomerOrderBatchHandler')
 
     def create(self, form=None, template='create'):
