@@ -27,6 +27,7 @@ DataSync Views
 from __future__ import unicode_literals, absolute_import
 
 import getpass
+import json
 import subprocess
 import logging
 
@@ -132,7 +133,7 @@ class DataSyncThreadView(MasterView):
         settings = []
         watch = []
 
-        for profile in data['profiles']:
+        for profile in json.loads(data['profiles']):
             pkey = profile['key']
             if profile['enabled']:
                 watch.append(pkey)
@@ -181,12 +182,12 @@ class DataSyncThreadView(MasterView):
                  'value': ', '.join(consumers)},
             ])
 
-        settings.extend([
-            {'name': 'rattail.datasync.watch',
-             'value': ', '.join(watch)},
-            {'name': 'tailbone.datasync.restart',
-             'value': data['restart_command']},
-        ])
+        if watch:
+            settings.append({'name': 'rattail.datasync.watch',
+                             'value': ', '.join(watch)})
+
+        settings.append({'name': 'tailbone.datasync.restart',
+                         'value': data['restart_command']})
 
         return settings
 
