@@ -2,7 +2,7 @@
 ################################################################################
 #
 #  Rattail -- Retail Software Framework
-#  Copyright © 2010-2021 Lance Edgar
+#  Copyright © 2010-2022 Lance Edgar
 #
 #  This file is part of Rattail.
 #
@@ -85,7 +85,7 @@ class EmailSettingView(MasterView):
 
     def get_handler(self):
         app = self.get_rattail_app()
-        return app.get_mail_handler()
+        return app.get_email_handler()
 
     def get_data(self, session=None):
         data = []
@@ -292,7 +292,7 @@ class EmailPreview(View):
 
     def get_handler(self):
         app = self.get_rattail_app()
-        return app.get_mail_handler()
+        return app.get_email_handler()
 
     def __call__(self):
 
