@@ -2,7 +2,7 @@
 ################################################################################
 #
 #  Rattail -- Retail Software Framework
-#  Copyright © 2010-2021 Lance Edgar
+#  Copyright © 2010-2022 Lance Edgar
 #
 #  This file is part of Rattail.
 #
@@ -62,6 +62,11 @@ class LabelProfileView(MasterView):
         'sync_me',
     ]
 
+    def __init__(self, request):
+        super(LabelProfileView, self).__init__(request)
+        app = self.get_rattail_app()
+        self.label_handler = app.get_label_handler()
+
     def configure_grid(self, g):
         super(LabelProfileView, self).configure_grid(g)
         g.set_sort_defaults('ordinal')
@@ -80,7 +85,7 @@ class LabelProfileView(MasterView):
 
     def after_edit(self, profile):
         if not profile.format:
-            formatter = profile.get_formatter(self.rattail_config)
+            formatter = self.label_handler.get_formatter(profile)
             if formatter:
                 try:
                     profile.format = formatter.default_format
@@ -122,17 +127,17 @@ class LabelProfileView(MasterView):
         View for editing extended Printer Settings, for a given Label Profile.
         """
         profile = self.get_instance()
-        read_profile = self.redirect(self.get_action_url('view', profile))
+        redirect = self.redirect(self.get_action_url('view', profile))
 
-        printer = profile.get_printer(self.rattail_config)
+        printer = self.label_handler.get_printer(profile)
         if not printer:
             msg = "Label profile \"{}\" does not have a functional printer spec.".format(profile)
             self.request.session.flash(msg)
-            return read_profile
+            return redirect
         if not printer.required_settings:
             msg = "Printer class for label profile \"{}\" does not require any settings.".format(profile)
             self.request.session.flash(msg)
-            return read_profile
+            return redirect
 
         form = self.make_printer_settings_form(profile, printer)
 
@@ -140,8 +145,9 @@ class LabelProfileView(MasterView):
         if self.request.method == 'POST':
             for setting in printer.required_settings:
                 if setting in self.request.POST:
-                    profile.save_printer_setting(setting, self.request.POST[setting])
-            return read_profile
+                    self.label_handler.save_printer_setting(
+                        profile, setting, self.request.POST[setting])
+            return redirect
 
         return self.render_to_response('printer', {
             'form': form,
