@@ -2,7 +2,7 @@
 ################################################################################
 #
 #  Rattail -- Retail Software Framework
-#  Copyright © 2010-2019 Lance Edgar
+#  Copyright © 2010-2021 Lance Edgar
 #
 #  This file is part of Rattail.
 #
@@ -42,7 +42,7 @@ from tailbone.views import MasterView
 from tailbone.util import raw_datetime
 
 
-class MessagesView(MasterView):
+class MessageView(MasterView):
     """
     Base class for message views.
     """
@@ -87,12 +87,12 @@ class MessagesView(MasterView):
     def index(self):
         if not self.request.user:
             raise httpexceptions.HTTPForbidden
-        return super(MessagesView, self).index()
+        return super(MessageView, self).index()
 
     def get_instance(self):
         if not self.request.user:
             raise httpexceptions.HTTPForbidden
-        message = super(MessagesView, self).get_instance()
+        message = super(MessageView, self).get_instance()
         if not self.associated_with(message):
             raise httpexceptions.HTTPForbidden
         return message
@@ -204,7 +204,7 @@ class MessagesView(MasterView):
 
     # TODO!!
     # def make_form(self, instance, **kwargs):
-    #     form = super(MessagesView, self).make_form(instance, **kwargs)
+    #     form = super(MessageView, self).make_form(instance, **kwargs)
     #     if self.creating:
     #         form.id = 'new-message'
     #         form.cancel_url = self.request.get_referrer(default=self.request.route_url('messages.inbox'))
@@ -212,7 +212,7 @@ class MessagesView(MasterView):
     #     return form
 
     def configure_form(self, f):
-        super(MessagesView, self).configure_form(f)
+        super(MessageView, self).configure_form(f)
         use_buefy = self.get_use_buefy()
 
         f.submit_label = "Send Message"
@@ -277,11 +277,17 @@ class MessagesView(MasterView):
                     value = [r[0] for r in value]
                     if old_message.sender is not self.request.user and old_message.sender.active:
                         value.insert(0, old_message.sender_uuid)
-                    f.set_default('set_recipients', ','.join(value))
+                    if use_buefy:
+                        f.set_default('set_recipients', value)
+                    else:
+                        f.set_default('set_recipients', ','.join(value))
 
                 # Just a normal reply, to sender only.
                 elif self.filter_reply_recipient(old_message.sender):
-                    f.set_default('set_recipients', old_message.sender.uuid)
+                    if use_buefy:
+                        f.set_default('set_recipients', [old_message.sender.uuid])
+                    else:
+                        f.set_default('set_recipients', old_message.sender.uuid)
 
                 # TODO?
                 # # Set focus to message body instead of recipients, when replying.
@@ -293,7 +299,7 @@ class MessagesView(MasterView):
     def objectify(self, form, data=None):
         if data is None:
             data = form.validated
-        message = super(MessagesView, self).objectify(form, data)
+        message = super(MessageView, self).objectify(form, data)
 
         if self.creating:
             if self.request.user:
@@ -469,8 +475,11 @@ class MessagesView(MasterView):
 
         cls._defaults(config)
 
+# TODO: deprecate / remove this
+MessagesView = MessageView
 
-class InboxView(MessagesView):
+
+class InboxView(MessageView):
     """
     Inbox message view.
     """
@@ -486,7 +495,7 @@ class InboxView(MessagesView):
         return q.filter(model.MessageRecipient.status == self.enum.MESSAGE_STATUS_INBOX)
 
 
-class ArchiveView(MessagesView):
+class ArchiveView(MessageView):
     """
     Archived message view.
     """
@@ -502,7 +511,7 @@ class ArchiveView(MessagesView):
         return q.filter(model.MessageRecipient.status == self.enum.MESSAGE_STATUS_ARCHIVE)
 
 
-class SentView(MessagesView):
+class SentView(MessageView):
     """
     Sent messages view.
     """
@@ -585,4 +594,4 @@ def includeme(config):
     config.add_view(SentView, attr='index', route_name='messages.sent',
                     permission='messages.list')
 
-    MessagesView.defaults(config)
+    MessageView.defaults(config)
