@@ -97,7 +97,7 @@ class ProductView(MasterView):
     }
 
     grid_columns = [
-        'upc',
+        '_product_key_',
         'brand',
         'description',
         'size',
@@ -108,9 +108,7 @@ class ProductView(MasterView):
     ]
 
     form_fields = [
-        'item_id',
-        'scancode',
-        'upc',
+        '_product_key_',
         'brand',
         'description',
         'unit_size',
@@ -181,9 +179,10 @@ class ProductView(MasterView):
             'tailbone', 'products.print_labels', default=False)
 
         app = self.get_rattail_app()
-        self.product_handler = app.get_products_handler()
-        # TODO: deprecate / remove this
-        self.handler = self.product_handler
+        self.products_handler = app.get_products_handler()
+        # TODO: deprecate / remove these
+        self.product_handler = self.products_handler
+        self.handler = self.products_handler
 
     def query(self, session):
         user = self.request.user
@@ -254,6 +253,15 @@ class ProductView(MasterView):
             return q.outerjoin(ProductCostCodeAny,
                                ProductCostCodeAny.product_uuid == model.Product.uuid)
 
+        # product key
+        key = self.rattail_config.product_key()
+        field = self.product_key_fields.get(key, key)
+        g.filters[field].default_active = True
+        g.filters[field].default_verb = 'equal'
+        g.set_sort_defaults(field)
+        g.set_link(field)
+
+        # brand
         g.joiners['brand'] = lambda q: q.outerjoin(model.Brand)
 
         # department
@@ -305,8 +313,6 @@ class ProductView(MasterView):
         g.set_sorter('on_order', model.ProductInventory.on_order)
         g.set_filter('on_order', model.ProductInventory.on_order)
 
-        g.filters['upc'].default_active = True
-        g.filters['upc'].default_verb = 'equal'
         g.filters['description'].default_active = True
         g.filters['description'].default_verb = 'contains'
         g.filters['brand'] = g.make_filter('brand', model.Brand.name,
@@ -367,8 +373,6 @@ class ProductView(MasterView):
         g.set_joiner('report_code_name', lambda q: q.outerjoin(model.ReportCode))
         g.set_filter('report_code_name', model.ReportCode.name)
 
-        g.set_sort_defaults('upc')
-
         if self.expose_label_printing and self.has_perm('print_labels'):
             if use_buefy:
                 g.more_actions.append(self.make_action(
@@ -377,13 +381,10 @@ class ProductView(MasterView):
             else:
                 g.more_actions.append(grids.GridAction('print_label', icon='print'))
 
-        g.set_type('upc', 'gpc')
-
         g.set_renderer('regular_price', self.render_price)
         g.set_renderer('on_hand', self.render_on_hand)
         g.set_renderer('on_order', self.render_on_order)
 
-        g.set_link('upc')
         g.set_link('item_id')
         g.set_link('description')
 
@@ -395,9 +396,6 @@ class ProductView(MasterView):
         super(ProductView, self).configure_common_form(f)
         product = f.model_instance
 
-        # upc
-        f.set_type('upc', 'gpc')
-
         # unit_size
         f.set_type('unit_size', 'quantity')
 
@@ -538,7 +536,7 @@ class ProductView(MasterView):
         if not product.not_for_sale:
             price = product[field]
             if price:
-                return self.product_handler.render_price(price)
+                return self.products_handler.render_price(price)
         
     def render_current_price_for_grid(self, product, field):
         text = self.render_price(product, field) or ""
@@ -1173,8 +1171,10 @@ class ProductView(MasterView):
         product = kwargs['instance']
         use_buefy = self.get_use_buefy()
 
-        kwargs['image_url'] = self.product_handler.get_image_url(product)
-        kwargs['product_key_field'] = self.rattail_config.product_key()
+        key = self.rattail_config.product_key()
+        kwargs['product_key_field'] = self.product_key_fields.get(key, key)
+
+        kwargs['image_url'] = self.products_handler.get_image_url(product)
 
         # add price history, if user has access
         if self.rattail_config.versioning_enabled() and self.has_perm('versions'):
@@ -1744,6 +1744,105 @@ class ProductView(MasterView):
         return {'ok': True}
 
     def search(self):
+        """
+        Perform a product search across multiple fields, and return
+        the results as JSON suitable for row data for a Buefy
+        ``<b-table>`` component.
+        """
+        if 'term' not in self.request.GET:
+            # TODO: deprecate / remove this?  not sure if/where it is used
+            return self.search_v1()
+
+        term = self.request.GET.get('term')
+        if not term:
+            return {'ok': True, 'results': []}
+
+        supported_fields = [
+            'product_key',
+            'vendor_code',
+            'alt_code',
+            'brand_name',
+            'description',
+        ]
+
+        search_fields = []
+        for field in supported_fields:
+            key = 'search_{}'.format(field)
+            if self.request.GET.get(key) == 'true':
+                search_fields.append(field)
+
+        final_results = []
+        session = self.Session()
+        model = self.model
+
+        lookup_fields = []
+        if 'product_key' in search_fields:
+            lookup_fields.append('_product_key_')
+        if 'vendor_code' in search_fields:
+            lookup_fields.append('vendor_code')
+        if 'alt_code' in search_fields:
+            lookup_fields.append('alt_code')
+        if lookup_fields:
+            product = self.products_handler.locate_product_for_entry(
+                session, term, lookup_fields=lookup_fields)
+            if product:
+                final_results.append(self.search_normalize_result(product))
+
+        # base wildcard query
+        query = session.query(model.Product)
+        if 'brand_name' in search_fields:
+            query = query.outerjoin(model.Brand)
+
+        # now figure out wildcard criteria
+        criteria = []
+        for word in term.split():
+            if 'brand_name' in search_fields and 'description' in search_fields:
+                criteria.append(sa.or_(
+                    model.Brand.name.ilike('%{}%'.format(word)),
+                    model.Product.description.ilike('%{}%'.format(word))))
+            elif 'brand_name' in search_fields:
+                criteria.append(model.Brand.name.ilike('%{}%'.format(word)))
+            elif 'description' in search_fields:
+                criteria.append(model.Product.description.ilike('%{}%'.format(word)))
+
+        # execute wildcard query if applicable
+        max_results = 30        # TODO: make conifgurable?
+        elided = 0
+        if criteria:
+            query = query.filter(sa.and_(*criteria))
+            count = query.count()
+            if count > max_results:
+                elided = count - max_results
+            for product in query[:max_results]:
+                final_results.append(self.search_normalize_result(product))
+
+        return {'ok': True, 'results': final_results, 'elided': elided}
+
+    def search_normalize_result(self, product, **kwargs):
+        return self.products_handler.normalize_product(product, fields=[
+            'product_key',
+            'url',
+            'image_url',
+            'brand_name',
+            'description',
+            'size',
+            'full_description',
+            'department_name',
+            'unit_price',
+            'unit_price_display',
+            'sale_price',
+            'sale_price_display',
+            'sale_ends_display',
+            'vendor_name',
+            # TODO: should be case_size
+            'case_quantity',
+            'case_price',
+            'case_price_display',
+            'uom_choices',
+        ])
+
+    # TODO: deprecate / remove this?  not sure if/where it is used
+    def search_v1(self):
         """
         Locate a product(s) by UPC.
 
@@ -2028,10 +2127,10 @@ class ProductView(MasterView):
                         renderer='{}/batch.mako'.format(template_prefix),
                         permission='{}.make_batch'.format(permission_prefix))
 
-        # search (by upc)
+        # search
         config.add_route('products.search', '/products/search')
         config.add_view(cls, attr='search', route_name='products.search',
-                        renderer='json', permission='products.view')
+                        renderer='json', permission='products.list')
 
         # product image
         config.add_route('products.image', '/products/{uuid}/image')
