@@ -2,7 +2,7 @@
 ################################################################################
 #
 #  Rattail -- Retail Software Framework
-#  Copyright © 2010-2021 Lance Edgar
+#  Copyright © 2010-2022 Lance Edgar
 #
 #  This file is part of Rattail.
 #
@@ -311,12 +311,12 @@ class PurchaseView(MasterView):
 
         purchase = self.get_instance()
         if purchase.status == self.enum.PURCHASE_STATUS_ORDERED:
-            g.hide_column('cases_received')
-            g.hide_column('units_received')
-            g.hide_column('invoice_total')
+            g.remove('cases_received',
+                     'units_received',
+                     'invoice_total')
         elif purchase.status in (self.enum.PURCHASE_STATUS_RECEIVED,
                                  self.enum.PURCHASE_STATUS_COSTED):
-            g.hide_column('po_total')
+            g.remove('po_total')
 
     def configure_row_form(self, f):
         super(PurchaseView, self).configure_row_form(f)
