@@ -2,7 +2,7 @@
 ################################################################################
 #
 #  Rattail -- Retail Software Framework
-#  Copyright © 2010-2021 Lance Edgar
+#  Copyright © 2010-2022 Lance Edgar
 #
 #  This file is part of Rattail.
 #
@@ -212,6 +212,7 @@ class ReportOutputView(ExportMasterView):
     model_class = model.ReportOutput
     route_prefix = 'report_output'
     url_prefix = '/reports/generated'
+    creatable = True
     downloadable = True
     configurable = True
     config_title = "Reporting"
@@ -235,6 +236,14 @@ class ReportOutputView(ExportMasterView):
         'created_by',
     ]
 
+    def __init__(self, request):
+        super(ReportOutputView, self).__init__(request)
+        self.report_handler = self.get_report_handler()
+
+    def get_report_handler(self):
+        app = self.get_rattail_app()
+        return app.get_report_handler()
+
     def configure_grid(self, g):
         super(ReportOutputView, self).configure_grid(g)
         g.set_link('filename')
@@ -245,10 +254,6 @@ class ReportOutputView(ExportMasterView):
         # params
         f.set_renderer('params', self.render_params)
 
-        # filename
-        if self.viewing:
-            f.set_renderer('filename', self.render_download)
-
     def render_params(self, report, field):
         params = report.params
         if not params:
@@ -273,11 +278,6 @@ class ReportOutputView(ExportMasterView):
         else:
             return HTML.literal(g.render_grid())
 
-    def render_download(self, report, field):
-        path = report.filepath(self.rattail_config)
-        url = self.get_action_url('download', report)
-        return self.render_file_field(path, url=url)
-
     def get_params_context(self, report):
         params_data = []
         for name, value in (report.params or {}).items():
@@ -305,36 +305,7 @@ class ReportOutputView(ExportMasterView):
 
         return kwargs
 
-    def download(self):
-        report = self.get_instance()
-        path = report.filepath(self.rattail_config)
-        return self.file_response(path)
-
-    def configure_get_simple_settings(self):
-        config = self.rattail_config
-        return [
-
-            # generating
-            {'section': 'tailbone',
-             'option': 'reporting.choosing_uses_form',
-             'type': bool},
-        ]
-
-
-class GenerateReport(View):
-    """
-    View for generating a new report.
-    """
-
-    def __init__(self, request):
-        super(GenerateReport, self).__init__(request)
-        self.handler = self.get_handler()
-
-    def get_handler(self):
-        app = self.get_rattail_app()
-        return app.get_report_handler()
-
-    def choose(self):
+    def create(self):
         """
         View which allows user to choose which type of report they wish to
         generate.
@@ -342,7 +313,7 @@ class GenerateReport(View):
         use_buefy = self.get_use_buefy()
 
         # handler is responsible for determining which report types are valid
-        reports = self.handler.get_reports()
+        reports = self.report_handler.get_reports()
         if isinstance(reports, OrderedDict):
             sorted_reports = list(reports)
         else:
@@ -370,18 +341,17 @@ class GenerateReport(View):
             raise self.redirect(self.request.route_url('generate_specific_report',
                                                        type_key=form.validated['report_type']))
 
-        return {
-            'index_title': "Generate Report",
+        return self.render_to_response('choose', {
             'form': form,
             'dform': form.make_deform_form(),
             'reports': reports,
             'sorted_reports': sorted_reports,
             'report_descriptions': dict([(r.type_key, r.__doc__)
                                          for r in reports.values()]),
-            'use_form': self.rattail_config.getbool('tailbone', 'reporting.choosing_uses_form',
-                                                    default=True),
-            'use_buefy': use_buefy,
-        }
+            'use_form': self.rattail_config.getbool(
+                'tailbone', 'reporting.choosing_uses_form',
+                default=True),
+        })
 
     def generate(self):
         """
@@ -391,8 +361,9 @@ class GenerateReport(View):
         """
         use_buefy = self.get_use_buefy()
         type_key = self.request.matchdict['type_key']
-        report = self.handler.get_report(type_key)
+        report = self.report_handler.get_report(type_key)
         report_params = report.make_params(Session())
+        route_prefix = self.get_route_prefix()
 
         NODE_TYPES = {
             bool: colander.Boolean,
@@ -401,6 +372,7 @@ class GenerateReport(View):
         }
 
         schema = colander.Schema()
+        helptext = {}
         for param in report_params:
 
             # make a new node of appropriate schema type
@@ -414,18 +386,21 @@ class GenerateReport(View):
 
             # allow empty value if param is optional
             if not param.required:
-                node.missing = colander.null
+                node.missing = None
 
             # maybe set default value
             if hasattr(param, 'default'):
                 node.default = param.default
 
+            # set docstring
+            helptext[param.name] = param.helptext
+
             schema.add(node)
 
         form = forms.Form(schema=schema, request=self.request,
-                          use_buefy=use_buefy)
+                          use_buefy=use_buefy, helptext=helptext)
         form.submit_label = "Generate this Report"
-        form.cancel_url = self.request.route_url('generate_report')
+        form.cancel_url = self.request.route_url('{}.create'.format(route_prefix))
 
         # must declare jquery support for date fields, ugh
         # TODO: obviously would be nice for this to be automatic?
@@ -454,14 +429,16 @@ class GenerateReport(View):
                 'cancel_msg': "Report generation was canceled",
             })
 
-        return {
-            'index_title': "Generate Report",
-            'index_url': self.request.route_url('generate_report'),
+        # hide the "Create New" button for this page, b/c user is
+        # already in the process of creating new..
+        # TODO: this seems hacky, but works
+        self.show_create_link = False
+
+        return self.render_to_response('generate', {
             'report': report,
             'form': form,
             'dform': form.make_deform_form(),
-            'use_buefy': self.get_use_buefy(),
-        }
+        })
 
     def generate_thread(self, report, params, user_uuid, progress=None):
         """
@@ -472,7 +449,7 @@ class GenerateReport(View):
         session = RattailSession()
         user = session.query(model.User).get(user_uuid)
         try:
-            output = self.handler.generate_output(session, report, params, user, progress=progress)
+            output = self.report_handler.generate_output(session, report, params, user, progress=progress)
 
         # if anything goes wrong, rollback and log the error etc.
         except Exception as error:
@@ -497,24 +474,36 @@ class GenerateReport(View):
                 progress.session['success_url'] = success_url
                 progress.session.save()
 
+    def download(self):
+        report = self.get_instance()
+        path = report.filepath(self.rattail_config)
+        return self.file_response(path)
+
+    def configure_get_simple_settings(self):
+        config = self.rattail_config
+        return [
+
+            # generating
+            {'section': 'tailbone',
+             'option': 'reporting.choosing_uses_form',
+             'type': bool},
+        ]
+
     @classmethod
     def defaults(cls, config):
+        cls._defaults(config)
+        cls._report_output_defaults(config)
 
-        # note that we include this in the "Generated Reports" permissions group
-        config.add_tailbone_permission('report_output', 'report_output.generate',
-                                       "Generate new report (of any type)")
+    @classmethod
+    def _report_output_defaults(cls, config):
+        url_prefix = cls.get_url_prefix()
+        permission_prefix = cls.get_permission_prefix()
 
-        # "generate report" (which is really "choose")
-        config.add_route('generate_report', '/reports/generate')
-        config.add_view(cls, attr='choose', route_name='generate_report',
-                        permission='report_output.generate',
-                        renderer='/reports/choose.mako')
-
-        # "generate specific report" (accept custom params, truly generate)
-        config.add_route('generate_specific_report', '/reports/generate/{type_key}')
+        # generate report (accept custom params, truly create)
+        config.add_route('generate_specific_report',
+                         '{}/new/{{type_key}}'.format(url_prefix))
         config.add_view(cls, attr='generate', route_name='generate_specific_report',
-                        permission='report_output.generate',
-                        renderer='/reports/generate.mako')
+                        permission='{}.create'.format(permission_prefix))
 
 
 @colander.deferred
@@ -585,7 +574,7 @@ class ProblemReportView(MasterView):
         }
 
         app = self.get_rattail_app()
-        handler = app.get_mail_handler()
+        handler = app.get_email_handler()
         email = handler.get_email(data['email_key'])
         data['email_recipients'] = email.get_recips('all')
 
@@ -676,18 +665,13 @@ def add_routes(config):
 
 
 def includeme(config):
-    add_routes(config)
 
+    # TODO: not in love with this pattern, but works for now
+    add_routes(config)
     config.add_view(OrderingWorksheet, route_name='reports.ordering',
                     renderer='/reports/ordering.mako')
-
     config.add_view(InventoryWorksheet, route_name='reports.inventory',
                     renderer='/reports/inventory.mako')
 
-    # fix permission group
-    config.add_tailbone_permission_group('report_output', "Generated Reports")
-
-    # note that GenerateReport must come first, per route matching
-    GenerateReport.defaults(config)
     ReportOutputView.defaults(config)
     ProblemReportView.defaults(config)
